# animated_wheel

A widget that implicitly rotates its child to the provided angle
in the direction allowed by the constraints: closest, furthest,
clockwise, or counter-clockwise.

# Usage

```dart
import 'package:animated_wheel/animated_wheel.dart';
```

[AnimatedWheel] accepts an [angle], in degrees by default, and implicitly
rotates its [child] to the [angle] whenever the [angle] is updated.

```dart
var angle = 180.0;

AnimatedWheel(
  angle: angle,
  child: MyWidget(),
);
```

## Scale

The [angle] can be normalized to any [scale]. By default, [angle] equates to
degrees (a [scale] of `360`.)

```dart
/// This [AnimatedWheel] is normalized to a `0` to `1` scale and currently
/// rotated to `0.5`, which is the equivalent of `180` on the default scale.
AnimatedWheel(
  angle: 0.5,
  scale: 1.0,
  child: MyWidget(),
);
```

## Duration

With the default settings, the [duration] of each animation will be factored
by the difference between the old [angle] and the new [angle], whenever [angle]
is updated. In this case, [duration] will equate to one whole rotation.

[factorDuration] can be set to `false` to have each animation last the entire
[duration].

[duration] defaults to `1` second.

```dart
/// If [angle] was changed from `0` to `180`, the duration of the
/// animation would be factored by `0.5` and last `500` milliseconds.
AnimatedWheel(
  angle: 180,
  duration: Duration(seconds: 1),
  child: MyWidget(),
);

/// In this case, where [factorDuration] is `false`, the duration
/// will last for the entire second.
AnimatedWheel(
  angle: 180,
  duration: Duration(seconds: 1),
  factorDuration: false,
  child: MyWidget(),
);
```

## Directions

By default the [child] will rotate in the direction that has the shorest span
to the new [angle] from the current [angle], whenever [angle] is updated.

[Direction] can be set to change how the direction of the rotation is
determined.

```dart
/// This [AnimatedWheel] will only rotate its child
/// in a clockwise direction.
AnimatedWheel(
  angle: 0,
  direction: RotationDirection.clockwise,
  child: MyWidget(),
);

/// This [AnimatedWheel] will only rotate its child
/// in a counter-clockwise direction.
AnimatedWheel(
  angle: 0,
  direction: RotationDirection.counterClockwise,
  child: MyWidget(),
);

/// This [AnimatedWheel] will rotate its child in the direction with
/// the shortest span from the current angle to the new angle.
AnimatedWheel(
  angle: 0,
  direction: RotationDirection.closest,
  child: MyWidget(),
);

/// This [AnimatedWheel] will rotate its child in the direction with
/// the longest span from the current angle to the new angle.
AnimatedWheel(
  angle: 0,
  direction: RotationDirection.furthest,
  child: MyWidget(),
);
```
